@@ -475,53 +475,53 @@
         <translation>Égaliseur</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="172"/>
-        <location filename="../eqwidget.cpp" line="189"/>
+        <location filename="../eqwidget.cpp" line="171"/>
+        <location filename="../eqwidget.cpp" line="188"/>
         <source>preset</source>
         <translation>réglage</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="273"/>
+        <location filename="../eqwidget.cpp" line="272"/>
         <source>&amp;Load/Delete</source>
         <translation>&amp;Charger / Supprimer</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="275"/>
+        <location filename="../eqwidget.cpp" line="274"/>
         <source>&amp;Save Preset</source>
         <translation>&amp;Enregistrer un réglage</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="277"/>
+        <location filename="../eqwidget.cpp" line="276"/>
         <source>&amp;Save Auto-load Preset</source>
         <translation>&amp;Enregistrer un réglage automatiquement chargé</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="279"/>
+        <location filename="../eqwidget.cpp" line="278"/>
         <source>&amp;Import</source>
         <translation>&amp;Importer</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="282"/>
+        <location filename="../eqwidget.cpp" line="281"/>
         <source>&amp;Clear</source>
         <translation>&amp;Effacer</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="311"/>
+        <location filename="../eqwidget.cpp" line="310"/>
         <source>Saving Preset</source>
         <translation>Réglage en cours d&apos;enregistrement</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="312"/>
+        <location filename="../eqwidget.cpp" line="311"/>
         <source>Preset name:</source>
         <translation>Nom du réglage : </translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="313"/>
+        <location filename="../eqwidget.cpp" line="312"/>
         <source>preset #</source>
         <translation>réglage #</translation>
     </message>
     <message>
-        <location filename="../eqwidget.cpp" line="404"/>
+        <location filename="../eqwidget.cpp" line="403"/>
         <source>Import Preset</source>
         <translation>Importer un réglage</translation>
     </message>
@@ -581,7 +581,7 @@
     <message>
         <location filename="../hotkeyeditor.cpp" line="94"/>
         <source>Do you want to restore default shortcuts?</source>
-        <translation>Voulez-vous restaurer les raccourcis par défaut ?</translation>
+        <translation>Voulez-vous restaurer les raccourcis par défaut&#xa0;?</translation>
     </message>
 </context>
 <context>
@@ -675,132 +675,132 @@
 <context>
     <name>MainVisual</name>
     <message>
-        <location filename="../mainvisual.cpp" line="213"/>
+        <location filename="../mainvisual.cpp" line="214"/>
         <source>Visualization Mode</source>
         <translation>Mode visualisation</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="216"/>
+        <location filename="../mainvisual.cpp" line="217"/>
         <source>Analyzer</source>
         <translation>Analyseur</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="217"/>
+        <location filename="../mainvisual.cpp" line="218"/>
         <source>Scope</source>
         <translation>Oscilloscope</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="218"/>
+        <location filename="../mainvisual.cpp" line="219"/>
         <source>Off</source>
         <translation>Arrêt</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="225"/>
+        <location filename="../mainvisual.cpp" line="226"/>
         <source>Analyzer Mode</source>
         <translation>Mode analyseur</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="228"/>
+        <location filename="../mainvisual.cpp" line="229"/>
         <source>Normal</source>
         <translation>Normal</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="229"/>
+        <location filename="../mainvisual.cpp" line="230"/>
         <source>Fire</source>
         <translation>Feu</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="230"/>
+        <location filename="../mainvisual.cpp" line="231"/>
         <source>Vertical Lines</source>
         <translation>Lignes verticales</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="231"/>
+        <location filename="../mainvisual.cpp" line="232"/>
         <source>Lines</source>
         <translation>Lignes</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="232"/>
+        <location filename="../mainvisual.cpp" line="233"/>
         <source>Bars</source>
         <translation>Barres</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="245"/>
+        <location filename="../mainvisual.cpp" line="246"/>
         <source>Peaks</source>
         <translation>Pics</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="249"/>
+        <location filename="../mainvisual.cpp" line="250"/>
         <source>Refresh Rate</source>
         <translation>Taux de rafraîchissement</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="252"/>
+        <location filename="../mainvisual.cpp" line="253"/>
         <source>50 fps</source>
         <translation>50 ips</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="253"/>
+        <location filename="../mainvisual.cpp" line="254"/>
         <source>25 fps</source>
         <translation>25 ips</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="254"/>
+        <location filename="../mainvisual.cpp" line="255"/>
         <source>10 fps</source>
         <translation>10 ips</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="255"/>
+        <location filename="../mainvisual.cpp" line="256"/>
         <source>5 fps</source>
         <translation>5 ips</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="262"/>
+        <location filename="../mainvisual.cpp" line="263"/>
         <source>Analyzer Falloff</source>
         <translation>Retombée de l&apos;analyseur</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="265"/>
-        <location filename="../mainvisual.cpp" line="279"/>
+        <location filename="../mainvisual.cpp" line="266"/>
+        <location filename="../mainvisual.cpp" line="280"/>
         <source>Slowest</source>
         <translation>Très lente</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="266"/>
-        <location filename="../mainvisual.cpp" line="280"/>
+        <location filename="../mainvisual.cpp" line="267"/>
+        <location filename="../mainvisual.cpp" line="281"/>
         <source>Slow</source>
         <translation>Lente</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="267"/>
-        <location filename="../mainvisual.cpp" line="281"/>
+        <location filename="../mainvisual.cpp" line="268"/>
+        <location filename="../mainvisual.cpp" line="282"/>
         <source>Medium</source>
         <translation>Moyenne</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="268"/>
-        <location filename="../mainvisual.cpp" line="282"/>
+        <location filename="../mainvisual.cpp" line="269"/>
+        <location filename="../mainvisual.cpp" line="283"/>
         <source>Fast</source>
         <translation>Rapide</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="269"/>
-        <location filename="../mainvisual.cpp" line="283"/>
+        <location filename="../mainvisual.cpp" line="270"/>
+        <location filename="../mainvisual.cpp" line="284"/>
         <source>Fastest</source>
         <translation>Très rapide</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="276"/>
+        <location filename="../mainvisual.cpp" line="277"/>
         <source>Peaks Falloff</source>
         <translation>Retombée des pics</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="289"/>
+        <location filename="../mainvisual.cpp" line="290"/>
         <source>Background</source>
         <translation>Arrière-plan</translation>
     </message>
     <message>
-        <location filename="../mainvisual.cpp" line="290"/>
+        <location filename="../mainvisual.cpp" line="291"/>
         <source>Transparent</source>
         <translation>Transparent</translation>
     </message>
@@ -851,118 +851,118 @@
         <translation>Liste</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="199"/>
+        <location filename="../playlist.cpp" line="197"/>
         <source>&amp;Copy Selection To</source>
         <translation>&amp;Copier la sélection vers</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="230"/>
+        <location filename="../playlist.cpp" line="228"/>
         <source>Sort List</source>
         <translation>Trier la liste</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="233"/>
-        <location filename="../playlist.cpp" line="273"/>
+        <location filename="../playlist.cpp" line="231"/>
+        <location filename="../playlist.cpp" line="271"/>
         <source>By Title</source>
         <translation>par titre</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="236"/>
-        <location filename="../playlist.cpp" line="276"/>
+        <location filename="../playlist.cpp" line="234"/>
+        <location filename="../playlist.cpp" line="274"/>
         <source>By Album</source>
         <translation>par album</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="257"/>
-        <location filename="../playlist.cpp" line="297"/>
+        <location filename="../playlist.cpp" line="255"/>
+        <location filename="../playlist.cpp" line="295"/>
         <source>By Disc Number</source>
         <translation>par numéro de disque</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="239"/>
-        <location filename="../playlist.cpp" line="279"/>
+        <location filename="../playlist.cpp" line="237"/>
+        <location filename="../playlist.cpp" line="277"/>
         <source>By Artist</source>
         <translation>par artiste</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="242"/>
-        <location filename="../playlist.cpp" line="282"/>
+        <location filename="../playlist.cpp" line="240"/>
+        <location filename="../playlist.cpp" line="280"/>
         <source>By Album Artist</source>
         <translation>par artiste d&apos;album</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="245"/>
-        <location filename="../playlist.cpp" line="285"/>
+        <location filename="../playlist.cpp" line="243"/>
+        <location filename="../playlist.cpp" line="283"/>
         <source>By Filename</source>
         <translation>par nom de fichier</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="248"/>
-        <location filename="../playlist.cpp" line="288"/>
+        <location filename="../playlist.cpp" line="246"/>
+        <location filename="../playlist.cpp" line="286"/>
         <source>By Path + Filename</source>
         <translation>par emplacement + nom de fichier</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="251"/>
-        <location filename="../playlist.cpp" line="291"/>
+        <location filename="../playlist.cpp" line="249"/>
+        <location filename="../playlist.cpp" line="289"/>
         <source>By Date</source>
         <translation>par date</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="254"/>
-        <location filename="../playlist.cpp" line="294"/>
+        <location filename="../playlist.cpp" line="252"/>
+        <location filename="../playlist.cpp" line="292"/>
         <source>By Track Number</source>
         <translation>par numéro de piste</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="260"/>
-        <location filename="../playlist.cpp" line="300"/>
+        <location filename="../playlist.cpp" line="258"/>
+        <location filename="../playlist.cpp" line="298"/>
         <source>By File Creation Date</source>
         <translation>par date de création du fichier</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="263"/>
-        <location filename="../playlist.cpp" line="303"/>
+        <location filename="../playlist.cpp" line="261"/>
+        <location filename="../playlist.cpp" line="301"/>
         <source>By File Modification Date</source>
         <translation>par date de modification du fichier</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="266"/>
+        <location filename="../playlist.cpp" line="264"/>
         <source>By Group</source>
         <translation>par groupe</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="271"/>
+        <location filename="../playlist.cpp" line="269"/>
         <source>Sort Selection</source>
         <translation>Trier la sélection</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="308"/>
+        <location filename="../playlist.cpp" line="306"/>
         <source>Randomize List</source>
         <translation>Mélanger la liste</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="310"/>
+        <location filename="../playlist.cpp" line="308"/>
         <source>Reverse List</source>
         <translation>Inverser la liste</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="317"/>
+        <location filename="../playlist.cpp" line="315"/>
         <source>Actions</source>
         <translation>Actions</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="592"/>
+        <location filename="../playlist.cpp" line="590"/>
         <source>Rename Playlist</source>
         <translation>Renommer la liste</translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="592"/>
+        <location filename="../playlist.cpp" line="590"/>
         <source>Playlist name:</source>
         <translation>Nom de la liste : </translation>
     </message>
     <message>
-        <location filename="../playlist.cpp" line="613"/>
+        <location filename="../playlist.cpp" line="611"/>
         <source>&amp;New PlayList</source>
         <translation>&amp;Nouvelle liste</translation>
     </message>
@@ -980,19 +980,19 @@
         <translation>Filtre : </translation>
     </message>
     <message>
-        <location filename="../forms/playlistbrowser.ui" line="43"/>
+        <location filename="../forms/playlistbrowser.ui" line="47"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="../forms/playlistbrowser.ui" line="50"/>
+        <location filename="../forms/playlistbrowser.ui" line="54"/>
         <location filename="../playlistbrowser.cpp" line="43"/>
         <source>Delete</source>
         <translation>Supprimer</translation>
     </message>
     <message>
-        <location filename="../forms/playlistbrowser.ui" line="57"/>
-        <location filename="../forms/playlistbrowser.ui" line="67"/>
+        <location filename="../forms/playlistbrowser.ui" line="61"/>
+        <location filename="../forms/playlistbrowser.ui" line="71"/>
         <source>...</source>
         <translation>…</translation>
     </message>
@@ -1172,7 +1172,7 @@
     <message>
         <location filename="../skinnedfactory.cpp" line="64"/>
         <source>Written by:</source>
-        <translation>Écrit par :</translation>
+        <translation>Écrit par&#xa0;:</translation>
     </message>
     <message>
         <location filename="../skinnedfactory.cpp" line="65"/>
@@ -1275,12 +1275,12 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="590"/>
         <source>Highlighted background:</source>
-        <translation>Arrière-plan en surbrillance :</translation>
+        <translation>Arrière-plan en surbrillance&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="494"/>
         <source>Normal text:</source>
-        <translation>Texte normal :</translation>
+        <translation>Texte normal&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="657"/>
@@ -1290,12 +1290,12 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="558"/>
         <source>Current text:</source>
-        <translation>Texte actuel :</translation>
+        <translation>Texte actuel&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="622"/>
         <source>Highlighted text:</source>
-        <translation>Texte en surbrillance :</translation>
+        <translation>Texte en surbrillance&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="765"/>
@@ -1310,7 +1310,7 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="730"/>
         <source>Group background:</source>
-        <translation>Arrière-plan de groupe :</translation>
+        <translation>Arrière-plan de groupe&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="860"/>
@@ -1320,12 +1320,12 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="698"/>
         <source>Group text:</source>
-        <translation>Texte de groupe :</translation>
+        <translation>Texte de groupe&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="449"/>
         <source>Background #1:</source>
-        <translation>Arrière-plan n°1 :</translation>
+        <translation>Arrière-plan n°1&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="825"/>
@@ -1345,7 +1345,7 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="984"/>
         <source>Column headers:</source>
-        <translation>Noms des colonnes :</translation>
+        <translation>Noms des colonnes&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="906"/>
@@ -1380,7 +1380,7 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="132"/>
         <source>Window title format:</source>
-        <translation>Format du titre de la fenêtre :</translation>
+        <translation>Format du titre de la fenêtre&#xa0;:</translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="97"/>
@@ -1480,7 +1480,7 @@
         <translation>Thème désarchivé</translation>
     </message>
     <message>
-        <location filename="../skinnedsettings.cpp" line="206"/>
+        <location filename="../skinnedsettings.cpp" line="217"/>
         <source>Archived skin</source>
         <translation>Thème archivé</translation>
     </message>
